# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class ActiveDirectoryObjectView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"sid": "str", "category": "str", "display_name": "str", "name": "str", "sam_account_name": "str"}

    attribute_map = {
        "sid": "sid",
        "category": "category",
        "display_name": "displayName",
        "name": "name",
        "sam_account_name": "samAccountName",
    }

    def __init__(
        self, sid=None, category=None, display_name=None, name=None, sam_account_name=None, _configuration=None
    ):  # noqa: E501
        """ActiveDirectoryObjectView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._sid = None
        self._category = None
        self._display_name = None
        self._name = None
        self._sam_account_name = None
        self.discriminator = None

        if sid is not None:
            self.sid = sid
        if category is not None:
            self.category = category
        if display_name is not None:
            self.display_name = display_name
        if name is not None:
            self.name = name
        if sam_account_name is not None:
            self.sam_account_name = sam_account_name

    @property
    def sid(self):
        """Gets the sid of this ActiveDirectoryObjectView.  # noqa: E501


        :return: The sid of this ActiveDirectoryObjectView.  # noqa: E501
        :rtype: str
        """
        return self._sid

    @sid.setter
    def sid(self, sid):
        """Sets the sid of this ActiveDirectoryObjectView.


        :param sid: The sid of this ActiveDirectoryObjectView.  # noqa: E501
        :type: str
        """

        self._sid = sid

    @property
    def category(self):
        """Gets the category of this ActiveDirectoryObjectView.  # noqa: E501


        :return: The category of this ActiveDirectoryObjectView.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this ActiveDirectoryObjectView.


        :param category: The category of this ActiveDirectoryObjectView.  # noqa: E501
        :type: str
        """
        allowed_values = ["Person", "Group"]  # noqa: E501
        if self._configuration.client_side_validation and category not in allowed_values:
            raise ValueError(
                "Invalid value for `category` ({0}), must be one of {1}".format(category, allowed_values)  # noqa: E501
            )

        self._category = category

    @property
    def display_name(self):
        """Gets the display_name of this ActiveDirectoryObjectView.  # noqa: E501


        :return: The display_name of this ActiveDirectoryObjectView.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this ActiveDirectoryObjectView.


        :param display_name: The display_name of this ActiveDirectoryObjectView.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def name(self):
        """Gets the name of this ActiveDirectoryObjectView.  # noqa: E501


        :return: The name of this ActiveDirectoryObjectView.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ActiveDirectoryObjectView.


        :param name: The name of this ActiveDirectoryObjectView.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def sam_account_name(self):
        """Gets the sam_account_name of this ActiveDirectoryObjectView.  # noqa: E501


        :return: The sam_account_name of this ActiveDirectoryObjectView.  # noqa: E501
        :rtype: str
        """
        return self._sam_account_name

    @sam_account_name.setter
    def sam_account_name(self, sam_account_name):
        """Sets the sam_account_name of this ActiveDirectoryObjectView.


        :param sam_account_name: The sam_account_name of this ActiveDirectoryObjectView.  # noqa: E501
        :type: str
        """

        self._sam_account_name = sam_account_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(ActiveDirectoryObjectView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActiveDirectoryObjectView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ActiveDirectoryObjectView):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class DCMEDeleteConnectionView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "deleted_connections": "list[DeletedConnectionView]",
        "deleted_data_sources": "list[DeletedDataSourceView]",
        "deleted_credentials": "list[DeletedCredentialView]",
    }

    attribute_map = {
        "deleted_connections": "deletedConnections",
        "deleted_data_sources": "deletedDataSources",
        "deleted_credentials": "deletedCredentials",
    }

    def __init__(
        self, deleted_connections=None, deleted_data_sources=None, deleted_credentials=None, _configuration=None
    ):  # noqa: E501
        """DCMEDeleteConnectionView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._deleted_connections = None
        self._deleted_data_sources = None
        self._deleted_credentials = None
        self.discriminator = None

        self.deleted_connections = deleted_connections
        self.deleted_data_sources = deleted_data_sources
        self.deleted_credentials = deleted_credentials

    @property
    def deleted_connections(self):
        """Gets the deleted_connections of this DCMEDeleteConnectionView.  # noqa: E501


        :return: The deleted_connections of this DCMEDeleteConnectionView.  # noqa: E501
        :rtype: list[DeletedConnectionView]
        """
        return self._deleted_connections

    @deleted_connections.setter
    def deleted_connections(self, deleted_connections):
        """Sets the deleted_connections of this DCMEDeleteConnectionView.


        :param deleted_connections: The deleted_connections of this DCMEDeleteConnectionView.  # noqa: E501
        :type: list[DeletedConnectionView]
        """
        if self._configuration.client_side_validation and deleted_connections is None:
            raise ValueError("Invalid value for `deleted_connections`, must not be `None`")  # noqa: E501

        self._deleted_connections = deleted_connections

    @property
    def deleted_data_sources(self):
        """Gets the deleted_data_sources of this DCMEDeleteConnectionView.  # noqa: E501


        :return: The deleted_data_sources of this DCMEDeleteConnectionView.  # noqa: E501
        :rtype: list[DeletedDataSourceView]
        """
        return self._deleted_data_sources

    @deleted_data_sources.setter
    def deleted_data_sources(self, deleted_data_sources):
        """Sets the deleted_data_sources of this DCMEDeleteConnectionView.


        :param deleted_data_sources: The deleted_data_sources of this DCMEDeleteConnectionView.  # noqa: E501
        :type: list[DeletedDataSourceView]
        """
        if self._configuration.client_side_validation and deleted_data_sources is None:
            raise ValueError("Invalid value for `deleted_data_sources`, must not be `None`")  # noqa: E501

        self._deleted_data_sources = deleted_data_sources

    @property
    def deleted_credentials(self):
        """Gets the deleted_credentials of this DCMEDeleteConnectionView.  # noqa: E501


        :return: The deleted_credentials of this DCMEDeleteConnectionView.  # noqa: E501
        :rtype: list[DeletedCredentialView]
        """
        return self._deleted_credentials

    @deleted_credentials.setter
    def deleted_credentials(self, deleted_credentials):
        """Sets the deleted_credentials of this DCMEDeleteConnectionView.


        :param deleted_credentials: The deleted_credentials of this DCMEDeleteConnectionView.  # noqa: E501
        :type: list[DeletedCredentialView]
        """
        if self._configuration.client_side_validation and deleted_credentials is None:
            raise ValueError("Invalid value for `deleted_credentials`, must not be `None`")  # noqa: E501

        self._deleted_credentials = deleted_credentials

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(DCMEDeleteConnectionView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DCMEDeleteConnectionView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DCMEDeleteConnectionView):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from src.server_client.api_client import ApiClient


class UsersApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def users_create_user(self, user_contract, **kwargs):  # noqa: E501
        """Create a new user.  # noqa: E501

        Only Curators can use this API endpoint.  This endpoint cannot be used for Windows Authentication configured
          Server instances.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_create_user(user_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateUserContract user_contract: The request body structure required to make a new user (required)
        :return: UserView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.users_create_user_with_http_info(user_contract, **kwargs)  # noqa: E501
        else:
            (data) = self.users_create_user_with_http_info(user_contract, **kwargs)  # noqa: E501
            return data

    def users_create_user_with_http_info(self, user_contract, **kwargs):  # noqa: E501
        """Create a new user.  # noqa: E501

        Only Curators can use this API endpoint.  This endpoint cannot be used for Windows Authentication configured
          Server instances.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_create_user_with_http_info(user_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateUserContract user_contract: The request body structure required to make a new user (required)
        :return: UserView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["user_contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method users_create_user" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'user_contract' is set
        if self.api_client.client_side_validation and (
            "user_contract" not in params or params["user_contract"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `user_contract` when calling `users_create_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "user_contract" in params:
            body_params = params["user_contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/users",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def users_deactivate_user(self, user_id, **kwargs):  # noqa: E501
        """Update an existing user as inactive.  # noqa: E501

        Only Curators can use this API endpoint.   An array of user group IDs that the deactivated user is removed from.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_deactivate_user(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Identifier for an existing user. (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.users_deactivate_user_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.users_deactivate_user_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def users_deactivate_user_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Update an existing user as inactive.  # noqa: E501

        Only Curators can use this API endpoint.   An array of user group IDs that the deactivated user is removed from.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_deactivate_user_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Identifier for an existing user. (required)
        :return: list[str]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["user_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method users_deactivate_user" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ("user_id" not in params or params["user_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `users_deactivate_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "user_id" in params:
            path_params["userId"] = params["user_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/users/{userId}/deactivate",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[str]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def users_delete_user(self, user_id, **kwargs):  # noqa: E501
        """Delete an existing user.  # noqa: E501

        Only Curators can use this API endpoint.  If the user has any assets(workflows, schedules, collections) 
        or exists within any user groups, then the user cannot be deleted.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_delete_user(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Identifier for an existing user. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.users_delete_user_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.users_delete_user_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def users_delete_user_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Delete an existing user.  # noqa: E501

        Only Curators can use this API endpoint.  If the user has any assets(workflows, schedules, collections)
          or exists within any user groups, then the user cannot be deleted.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_delete_user_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Identifier for an existing user. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["user_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method users_delete_user" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ("user_id" not in params or params["user_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `users_delete_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "user_id" in params:
            path_params["userId"] = params["user_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/users/{userId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def users_get_user(self, user_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing user.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Identifier for an existing user. (required)
        :return: UserView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.users_get_user_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.users_get_user_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def users_get_user_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing user.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_user_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Identifier for an existing user. (required)
        :return: UserView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["user_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method users_get_user" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ("user_id" not in params or params["user_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `users_get_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "user_id" in params:
            path_params["userId"] = params["user_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/users/{userId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def users_get_users(self, **kwargs):  # noqa: E501
        """Retrieve all accessible user records.  # noqa: E501

        Only Curators can use this API endpoint.  If the searchContract.Verbose is set to false, then a reduced view
          object will be returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_users(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view:
        :param bool active:
        :param str email:
        :param str role:
        :param str first_name:
        :param str last_name:
        :param datetime created_after:
        :param datetime created_before:
        :return: list[UserView]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.users_get_users_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.users_get_users_with_http_info(**kwargs)  # noqa: E501
            return data

    def users_get_users_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve all accessible user records.  # noqa: E501

        Only Curators can use this API endpoint.  If the searchContract.Verbose is set to false, then a reduced view
        object will be returned.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_users_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view:
        :param bool active:
        :param str email:
        :param str role:
        :param str first_name:
        :param str last_name:
        :param datetime created_after:
        :param datetime created_before:
        :return: list[UserView]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["view", "active", "email", "role", "first_name", "last_name", "created_after", "created_before"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method users_get_users" % key)
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "view" in params:
            query_params.append(("view", params["view"]))  # noqa: E501
        if "active" in params:
            query_params.append(("active", params["active"]))  # noqa: E501
        if "email" in params:
            query_params.append(("email", params["email"]))  # noqa: E501
        if "role" in params:
            query_params.append(("role", params["role"]))  # noqa: E501
        if "first_name" in params:
            query_params.append(("firstName", params["first_name"]))  # noqa: E501
        if "last_name" in params:
            query_params.append(("lastName", params["last_name"]))  # noqa: E501
        if "created_after" in params:
            query_params.append(("createdAfter", params["created_after"]))  # noqa: E501
        if "created_before" in params:
            query_params.append(("createdBefore", params["created_before"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/users",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[UserView]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def users_get_users_assets(self, user_id, **kwargs):  # noqa: E501
        """Retrieve all accessible assets owned by an existing user.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_users_assets(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Identifier for an existing user. (required)
        :param str asset_type: The type of assets I want to return (defaulted to All)
        :return: AssetsView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.users_get_users_assets_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.users_get_users_assets_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def users_get_users_assets_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Retrieve all accessible assets owned by an existing user.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_get_users_assets_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Identifier for an existing user. (required)
        :param str asset_type: The type of assets I want to return (defaulted to All)
        :return: AssetsView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["user_id", "asset_type"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method users_get_users_assets" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ("user_id" not in params or params["user_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `users_get_users_assets`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "user_id" in params:
            path_params["userId"] = params["user_id"]  # noqa: E501

        query_params = []
        if "asset_type" in params:
            query_params.append(("assetType", params["asset_type"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/users/{userId}/assets",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="AssetsView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def users_send_password_reset(self, user_id, **kwargs):  # noqa: E501
        """Send a password reset email to an existing user.  # noqa: E501

        Only Curators can use this API endpoint.  This endpoint cannot be used for Windows Authentication
          configured Server instances.  This endpoint cannot be used for SAML Authentication configured 
          Server instances.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_send_password_reset(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Identifier for an existing user. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.users_send_password_reset_with_http_info(user_id, **kwargs)  # noqa: E501
        else:
            (data) = self.users_send_password_reset_with_http_info(user_id, **kwargs)  # noqa: E501
            return data

    def users_send_password_reset_with_http_info(self, user_id, **kwargs):  # noqa: E501
        """Send a password reset email to an existing user.  # noqa: E501

        Only Curators can use this API endpoint.  This endpoint cannot be used for Windows Authentication configured
          Server instances.  This endpoint cannot be used for SAML Authentication configured Server instances.
              # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_send_password_reset_with_http_info(user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Identifier for an existing user. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["user_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method users_send_password_reset" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ("user_id" not in params or params["user_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `users_send_password_reset`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "user_id" in params:
            path_params["userId"] = params["user_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/users/{userId}/passwordReset",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def users_transfer_assets(self, user_id, contract, **kwargs):  # noqa: E501
        """Transfer all assets (workflows, schedules, collections) owned by one user to another.  # noqa: E501

        If any of the workflows require DCM connections, server connections, or specific run as credentials to run,
        these items will need to be updated before the workflow can run.   Additionally, if users are not in the
        same studio, when a workflow is transferred to the new studio, all other users in the new owner's studio
        will also receive access to the workflow, and all users from the old studio will lose access.
        Returns a list of schedule ids that will be broken or disabled after transfer if user is deleted.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_transfer_assets(user_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Id of the user to transfer assets from. (required)
        :param TransferUserAssetsContract contract:  (required)
        :return: list[AffectedScheduleView]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.users_transfer_assets_with_http_info(user_id, contract, **kwargs)  # noqa: E501
        else:
            (data) = self.users_transfer_assets_with_http_info(user_id, contract, **kwargs)  # noqa: E501
            return data

    def users_transfer_assets_with_http_info(self, user_id, contract, **kwargs):  # noqa: E501
        """Transfer all assets (workflows, schedules, collections) owned by one user to another.  # noqa: E501

        If any of the workflows require DCM connections, server connections, or specific run as credentials to run,
        these items will need to be updated before the workflow can run.   
        Additionally, if users are not in the same studio, when a workflow is transferred to the new studio, 
        all other users in the new owner's studio will also receive access to the workflow,   
        and all users from the old studio will lose access.
        Returns a list of schedule ids that will be broken or disabled after transfer if user is deleted.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_transfer_assets_with_http_info(user_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Id of the user to transfer assets from. (required)
        :param TransferUserAssetsContract contract:  (required)
        :return: list[AffectedScheduleView]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["user_id", "contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method users_transfer_assets" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ("user_id" not in params or params["user_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `users_transfer_assets`")  # noqa: E501
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `contract` when calling `users_transfer_assets`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "user_id" in params:
            path_params["userId"] = params["user_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/users/{userId}/assetTransfer",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[AffectedScheduleView]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def users_update_user(self, user_id, update_contract, **kwargs):  # noqa: E501
        """Update details of an existing user.  # noqa: E501

        Only Curators can use this API endpoint.  The Id of the updateContract will be 
        overwritten by the id value in the URL.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_update_user(user_id, update_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Identifier for an existing user. (required)
        :param UpdateUserContract update_contract: The request body structure (required)
        :return: UserView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.users_update_user_with_http_info(user_id, update_contract, **kwargs)  # noqa: E501
        else:
            (data) = self.users_update_user_with_http_info(user_id, update_contract, **kwargs)  # noqa: E501
            return data

    def users_update_user_with_http_info(self, user_id, update_contract, **kwargs):  # noqa: E501
        """Update details of an existing user.  # noqa: E501

        Only Curators can use this API endpoint.  The Id of the updateContract will be overwritten by
          the id value in the URL.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.users_update_user_with_http_info(user_id, update_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str user_id: Identifier for an existing user. (required)
        :param UpdateUserContract update_contract: The request body structure (required)
        :return: UserView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["user_id", "update_contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError("Got an unexpected keyword argument '%s' to method users_update_user" % key)
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ("user_id" not in params or params["user_id"] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `user_id` when calling `users_update_user`")  # noqa: E501
        # verify the required parameter 'update_contract' is set
        if self.api_client.client_side_validation and (
            "update_contract" not in params or params["update_contract"] is None
        ):  # noqa: E501
            raise ValueError("Missing the required parameter `update_contract` when calling `users_update_user`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "user_id" in params:
            path_params["userId"] = params["user_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_contract" in params:
            body_params = params["update_contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/users/{userId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class UserGroupAddedUsersView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "successfully_added_user_count": "int",
        "total_users_submitted_count": "int",
        "failed_user_reasons": "dict(str, str)",
    }

    attribute_map = {
        "successfully_added_user_count": "successfullyAddedUserCount",
        "total_users_submitted_count": "totalUsersSubmittedCount",
        "failed_user_reasons": "failedUserReasons",
    }

    def __init__(
        self,
        successfully_added_user_count=None,
        total_users_submitted_count=None,
        failed_user_reasons=None,
        _configuration=None,
    ):  # noqa: E501
        """UserGroupAddedUsersView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._successfully_added_user_count = None
        self._total_users_submitted_count = None
        self._failed_user_reasons = None
        self.discriminator = None

        self.successfully_added_user_count = successfully_added_user_count
        self.total_users_submitted_count = total_users_submitted_count
        if failed_user_reasons is not None:
            self.failed_user_reasons = failed_user_reasons

    @property
    def successfully_added_user_count(self):
        """Gets the successfully_added_user_count of this UserGroupAddedUsersView.  # noqa: E501


        :return: The successfully_added_user_count of this UserGroupAddedUsersView.  # noqa: E501
        :rtype: int
        """
        return self._successfully_added_user_count

    @successfully_added_user_count.setter
    def successfully_added_user_count(self, successfully_added_user_count):
        """Sets the successfully_added_user_count of this UserGroupAddedUsersView.


        :param successfully_added_user_count: The successfully_added_user_count
          of this UserGroupAddedUsersView.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and successfully_added_user_count is None:
            raise ValueError("Invalid value for `successfully_added_user_count`, must not be `None`")  # noqa: E501

        self._successfully_added_user_count = successfully_added_user_count

    @property
    def total_users_submitted_count(self):
        """Gets the total_users_submitted_count of this UserGroupAddedUsersView.  # noqa: E501


        :return: The total_users_submitted_count of this UserGroupAddedUsersView.  # noqa: E501
        :rtype: int
        """
        return self._total_users_submitted_count

    @total_users_submitted_count.setter
    def total_users_submitted_count(self, total_users_submitted_count):
        """Sets the total_users_submitted_count of this UserGroupAddedUsersView.


        :param total_users_submitted_count: The total_users_submitted_count of
        this UserGroupAddedUsersView.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and total_users_submitted_count is None:
            raise ValueError("Invalid value for `total_users_submitted_count`, must not be `None`")  # noqa: E501

        self._total_users_submitted_count = total_users_submitted_count

    @property
    def failed_user_reasons(self):
        """Gets the failed_user_reasons of this UserGroupAddedUsersView.  # noqa: E501


        :return: The failed_user_reasons of this UserGroupAddedUsersView.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._failed_user_reasons

    @failed_user_reasons.setter
    def failed_user_reasons(self, failed_user_reasons):
        """Sets the failed_user_reasons of this UserGroupAddedUsersView.


        :param failed_user_reasons: The failed_user_reasons of this UserGroupAddedUsersView.  # noqa: E501
        :type: dict(str, str)
        """

        self._failed_user_reasons = failed_user_reasons

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserGroupAddedUsersView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserGroupAddedUsersView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserGroupAddedUsersView):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class Subscription(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "name": "str",
        "api_key": "str",
        "api_secret": "str",
        "active": "bool",
        "expiration_date": "str",
        "exp_date": "datetime",
        "date_updated": "datetime",
        "api_enabled": "bool",
        "can_share_schedules": "bool",
        "credential_id": "str",
        "credentials": "list[SubscriptionCredential]",
        "data_connections": "list[SubscriptionDataConnection]",
        "id": "str",
    }

    attribute_map = {
        "name": "name",
        "api_key": "apiKey",
        "api_secret": "apiSecret",
        "active": "active",
        "expiration_date": "expirationDate",
        "exp_date": "expDate",
        "date_updated": "dateUpdated",
        "api_enabled": "apiEnabled",
        "can_share_schedules": "canShareSchedules",
        "credential_id": "credentialId",
        "credentials": "credentials",
        "data_connections": "dataConnections",
        "id": "id",
    }

    def __init__(
        self,
        name=None,
        api_key=None,
        api_secret=None,
        active=None,
        expiration_date=None,
        exp_date=None,
        date_updated=None,
        api_enabled=None,
        can_share_schedules=None,
        credential_id=None,
        credentials=None,
        data_connections=None,
        id=None,
        _configuration=None,
    ):  # noqa: E501
        """Subscription - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._api_key = None
        self._api_secret = None
        self._active = None
        self._expiration_date = None
        self._exp_date = None
        self._date_updated = None
        self._api_enabled = None
        self._can_share_schedules = None
        self._credential_id = None
        self._credentials = None
        self._data_connections = None
        self._id = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if api_key is not None:
            self.api_key = api_key
        if api_secret is not None:
            self.api_secret = api_secret
        if active is not None:
            self.active = active
        if expiration_date is not None:
            self.expiration_date = expiration_date
        if exp_date is not None:
            self.exp_date = exp_date
        if date_updated is not None:
            self.date_updated = date_updated
        if api_enabled is not None:
            self.api_enabled = api_enabled
        if can_share_schedules is not None:
            self.can_share_schedules = can_share_schedules
        if credential_id is not None:
            self.credential_id = credential_id
        if credentials is not None:
            self.credentials = credentials
        if data_connections is not None:
            self.data_connections = data_connections
        if id is not None:
            self.id = id

    @property
    def name(self):
        """Gets the name of this Subscription.  # noqa: E501


        :return: The name of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Subscription.


        :param name: The name of this Subscription.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def api_key(self):
        """Gets the api_key of this Subscription.  # noqa: E501


        :return: The api_key of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._api_key

    @api_key.setter
    def api_key(self, api_key):
        """Sets the api_key of this Subscription.


        :param api_key: The api_key of this Subscription.  # noqa: E501
        :type: str
        """

        self._api_key = api_key

    @property
    def api_secret(self):
        """Gets the api_secret of this Subscription.  # noqa: E501


        :return: The api_secret of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._api_secret

    @api_secret.setter
    def api_secret(self, api_secret):
        """Sets the api_secret of this Subscription.


        :param api_secret: The api_secret of this Subscription.  # noqa: E501
        :type: str
        """

        self._api_secret = api_secret

    @property
    def active(self):
        """Gets the active of this Subscription.  # noqa: E501


        :return: The active of this Subscription.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this Subscription.


        :param active: The active of this Subscription.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def expiration_date(self):
        """Gets the expiration_date of this Subscription.  # noqa: E501


        :return: The expiration_date of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._expiration_date

    @expiration_date.setter
    def expiration_date(self, expiration_date):
        """Sets the expiration_date of this Subscription.


        :param expiration_date: The expiration_date of this Subscription.  # noqa: E501
        :type: str
        """

        self._expiration_date = expiration_date

    @property
    def exp_date(self):
        """Gets the exp_date of this Subscription.  # noqa: E501


        :return: The exp_date of this Subscription.  # noqa: E501
        :rtype: datetime
        """
        return self._exp_date

    @exp_date.setter
    def exp_date(self, exp_date):
        """Sets the exp_date of this Subscription.


        :param exp_date: The exp_date of this Subscription.  # noqa: E501
        :type: datetime
        """

        self._exp_date = exp_date

    @property
    def date_updated(self):
        """Gets the date_updated of this Subscription.  # noqa: E501


        :return: The date_updated of this Subscription.  # noqa: E501
        :rtype: datetime
        """
        return self._date_updated

    @date_updated.setter
    def date_updated(self, date_updated):
        """Sets the date_updated of this Subscription.


        :param date_updated: The date_updated of this Subscription.  # noqa: E501
        :type: datetime
        """

        self._date_updated = date_updated

    @property
    def api_enabled(self):
        """Gets the api_enabled of this Subscription.  # noqa: E501


        :return: The api_enabled of this Subscription.  # noqa: E501
        :rtype: bool
        """
        return self._api_enabled

    @api_enabled.setter
    def api_enabled(self, api_enabled):
        """Sets the api_enabled of this Subscription.


        :param api_enabled: The api_enabled of this Subscription.  # noqa: E501
        :type: bool
        """

        self._api_enabled = api_enabled

    @property
    def can_share_schedules(self):
        """Gets the can_share_schedules of this Subscription.  # noqa: E501


        :return: The can_share_schedules of this Subscription.  # noqa: E501
        :rtype: bool
        """
        return self._can_share_schedules

    @can_share_schedules.setter
    def can_share_schedules(self, can_share_schedules):
        """Sets the can_share_schedules of this Subscription.


        :param can_share_schedules: The can_share_schedules of this Subscription.  # noqa: E501
        :type: bool
        """

        self._can_share_schedules = can_share_schedules

    @property
    def credential_id(self):
        """Gets the credential_id of this Subscription.  # noqa: E501


        :return: The credential_id of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._credential_id

    @credential_id.setter
    def credential_id(self, credential_id):
        """Sets the credential_id of this Subscription.


        :param credential_id: The credential_id of this Subscription.  # noqa: E501
        :type: str
        """

        self._credential_id = credential_id

    @property
    def credentials(self):
        """Gets the credentials of this Subscription.  # noqa: E501


        :return: The credentials of this Subscription.  # noqa: E501
        :rtype: list[SubscriptionCredential]
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """Sets the credentials of this Subscription.


        :param credentials: The credentials of this Subscription.  # noqa: E501
        :type: list[SubscriptionCredential]
        """

        self._credentials = credentials

    @property
    def data_connections(self):
        """Gets the data_connections of this Subscription.  # noqa: E501


        :return: The data_connections of this Subscription.  # noqa: E501
        :rtype: list[SubscriptionDataConnection]
        """
        return self._data_connections

    @data_connections.setter
    def data_connections(self, data_connections):
        """Sets the data_connections of this Subscription.


        :param data_connections: The data_connections of this Subscription.  # noqa: E501
        :type: list[SubscriptionDataConnection]
        """

        self._data_connections = data_connections

    @property
    def id(self):
        """Gets the id of this Subscription.  # noqa: E501


        :return: The id of this Subscription.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Subscription.


        :param id: The id of this Subscription.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(Subscription, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Subscription):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Subscription):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class IterationMonthlyContract(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"simple_day_of_month": "bool", "day_of_month": "int", "occurrence": "int", "day_of_week": "str"}

    attribute_map = {
        "simple_day_of_month": "simpleDayOfMonth",
        "day_of_month": "dayOfMonth",
        "occurrence": "occurrence",
        "day_of_week": "dayOfWeek",
    }

    def __init__(
        self, simple_day_of_month=None, day_of_month=None, occurrence=None, day_of_week=None, _configuration=None
    ):  # noqa: E501
        """IterationMonthlyContract - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._simple_day_of_month = None
        self._day_of_month = None
        self._occurrence = None
        self._day_of_week = None
        self.discriminator = None

        self.simple_day_of_month = simple_day_of_month
        if day_of_month is not None:
            self.day_of_month = day_of_month
        if occurrence is not None:
            self.occurrence = occurrence
        if day_of_week is not None:
            self.day_of_week = day_of_week

    @property
    def simple_day_of_month(self):
        """Gets the simple_day_of_month of this IterationMonthlyContract.  # noqa: E501


        :return: The simple_day_of_month of this IterationMonthlyContract.  # noqa: E501
        :rtype: bool
        """
        return self._simple_day_of_month

    @simple_day_of_month.setter
    def simple_day_of_month(self, simple_day_of_month):
        """Sets the simple_day_of_month of this IterationMonthlyContract.


        :param simple_day_of_month: The simple_day_of_month of this IterationMonthlyContract.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and simple_day_of_month is None:
            raise ValueError("Invalid value for `simple_day_of_month`, must not be `None`")  # noqa: E501

        self._simple_day_of_month = simple_day_of_month

    @property
    def day_of_month(self):
        """Gets the day_of_month of this IterationMonthlyContract.  # noqa: E501

        15 would be the 15th of each month.  Required when SimpleDayOfMonth is true.  # noqa: E501

        :return: The day_of_month of this IterationMonthlyContract.  # noqa: E501
        :rtype: int
        """
        return self._day_of_month

    @day_of_month.setter
    def day_of_month(self, day_of_month):
        """Sets the day_of_month of this IterationMonthlyContract.

        15 would be the 15th of each month.  Required when SimpleDayOfMonth is true.  # noqa: E501

        :param day_of_month: The day_of_month of this IterationMonthlyContract.  # noqa: E501
        :type: int
        """

        self._day_of_month = day_of_month

    @property
    def occurrence(self):
        """Gets the occurrence of this IterationMonthlyContract.  # noqa: E501

        3 would imply the 3rd X of every month.  Required when SimpleDayOfMonth is false.  # noqa: E501

        :return: The occurrence of this IterationMonthlyContract.  # noqa: E501
        :rtype: int
        """
        return self._occurrence

    @occurrence.setter
    def occurrence(self, occurrence):
        """Sets the occurrence of this IterationMonthlyContract.

        3 would imply the 3rd X of every month.  Required when SimpleDayOfMonth is false.  # noqa: E501

        :param occurrence: The occurrence of this IterationMonthlyContract.  # noqa: E501
        :type: int
        """

        self._occurrence = occurrence

    @property
    def day_of_week(self):
        """Gets the day_of_week of this IterationMonthlyContract.  # noqa: E501

        0 = \"Sunday\"  0 implies the Xth Sunday of every month.  Required when SimpleDayOfMonth is false.  # noqa: E501

        :return: The day_of_week of this IterationMonthlyContract.  # noqa: E501
        :rtype: str
        """
        return self._day_of_week

    @day_of_week.setter
    def day_of_week(self, day_of_week):
        """Sets the day_of_week of this IterationMonthlyContract.

        0 = \"Sunday\"  0 implies the Xth Sunday of every month.  Required when SimpleDayOfMonth is false.  # noqa: E501

        :param day_of_week: The day_of_week of this IterationMonthlyContract.  # noqa: E501
        :type: str
        """
        allowed_values = ["Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"]  # noqa: E501
        if self._configuration.client_side_validation and day_of_week not in allowed_values:
            raise ValueError(
                "Invalid value for `day_of_week` ({0}), must be one of {1}".format(day_of_week, allowed_values)  # noqa: E501
            )

        self._day_of_week = day_of_week

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(IterationMonthlyContract, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IterationMonthlyContract):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IterationMonthlyContract):
            return True

        return self.to_dict() != other.to_dict()



import os

ALTERYX_CLIENT_ID = os.getenv("ALTERYX_CLIENT_ID")
ALTERYX_CLIENT_SECRET = os.getenv("ALTERYX_CLIENT_SECRET")

ALTERYX_API_HOST = os.getenv("ALTERYX_API_HOST", "http://localhost/webapi/")

ALTERYX_VERIFY_SSL = os.getenv("ALTERYX_VERIFY_SSL", "1").lower() not in ("0", "false", "no")

ALTERYX_USERNAME = os.getenv("ALTERYX_USERNAME")
ALTERYX_PASSWORD = os.getenv("ALTERYX_PASSWORD")



import src.server_client as server_client
from src.server_client.rest import ApiException
from typing import List, Optional, Dict, Any
import pprint
import tempfile
import zipfile
import os
import shutil
from pydantic import BaseModel
import xml.etree.ElementTree as ET
import time


class InputData(BaseModel):
    name: str
    value: str


class AYXMCPTools:
    def __init__(self):
        """Initialize the Alteryx Server Client with API instances"""
        self.configuration = server_client.Configuration()
        self.collections_api = server_client.CollectionsApi(server_client.ApiClient(self.configuration))
        self.workflows_api = server_client.WorkflowsApi(server_client.ApiClient(self.configuration))
        self.users_api = server_client.UsersApi(server_client.ApiClient(self.configuration))
        self.jobs_api = server_client.JobsApi(server_client.ApiClient(self.configuration))
        self.credentials_api = server_client.CredentialsApi(server_client.ApiClient(self.configuration))
        self.dcm_api = server_client.DCMEApi(server_client.ApiClient(self.configuration))
        self.schedules_api = server_client.SchedulesApi(server_client.ApiClient(self.configuration))

    # Collections functions
    def get_all_collections(self):
        """Get the list of all collections of the Alteryx server"""
        try:
            api_response = self.collections_api.collections_get_collections()
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def get_collection_by_id(self, collection_id: str):
        """Get a collection by its ID"""
        try:
            api_response = self.collections_api.collections_get_collection(collection_id)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def create_collection(self, name: str):
        """Create a new collection. To add a collection to a user, use the update_collection_name_or_owner function."""
        try:
            contract = server_client.CreateCollectionContract(name=name)
            api_response = self.collections_api.collections_create_collection(contract)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def delete_collection(self, collection_id: str):
        """Delete a collection by its ID"""
        try:
            collection = self.collections_api.collections_get_collection(collection_id)
            if not collection:
                return "Error: Collection not found"
            api_response = self.collections_api.collections_delete_collection(collection_id)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def update_collection_name_or_owner(self, collection_id: str, name: str, owner_id: str):
        """Update a collection name or owner by its ID"""
        try:
            collection = self.collections_api.collections_get_collection(collection_id)
            if not collection:
                return "Error: Collection not found"
            contract = server_client.UpdateCollectionContract(
                name=name if name else collection.name, owner_id=owner_id if owner_id else collection.owner_id
            )
            api_response = self.collections_api.collections_update_collection(collection_id, contract)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def add_workflow_to_collection(self, collection_id: str, workflow_id: str):
        """Add a workflow to a collection by its ID"""
        try:
            collection = self.collections_api.collections_get_collection(collection_id)
            if not collection:
                return "Error: Collection not found"
            workflow = self.workflows_api.workflows_get_workflow(workflow_id)
            if not workflow:
                return "Error: Workflow not found"
            contract = server_client.AddWorkflowContract(workflow_id=workflow_id)
            api_response = self.collections_api.collections_add_workflow_to_collection(collection_id, contract)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def remove_workflow_from_collection(self, collection_id: str, workflow_id: str):
        """Remove a workflow from a collection by its ID"""
        try:
            collection = self.collections_api.collections_get_collection(collection_id)
            if not collection:
                return "Error: Collection not found"
            workflow = self.workflows_api.workflows_get_workflow(workflow_id)
            if not workflow:
                return "Error: Workflow not found"
            api_response = self.collections_api.collections_remove_workflow_from_collection(collection_id, workflow_id)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def add_schedule_to_collection(self, collection_id: str, schedule_id: str):
        """Add a schedule to a collection by its ID"""
        try:
            collection = self.collections_api.collections_get_collection(collection_id)
            if not collection:
                return "Error: Collection not found"
            schedule = self.schedules_api.schedules_get_schedule(schedule_id)
            if not schedule:
                return "Error: Schedule not found"
            contract = server_client.AddScheduleContract(schedule_id=schedule_id)
            api_response = self.collections_api.collections_add_schedule_to_collection(collection_id, contract)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def remove_schedule_from_collection(self, collection_id: str, schedule_id: str):
        """Remove a schedule from a collection by its ID"""
        try:
            collection = self.collections_api.collections_get_collection(collection_id)
            if not collection:
                return "Error: Collection not found"
            schedule = self.schedules_api.schedules_get_schedule(schedule_id)
            if not schedule:
                return "Error: Schedule not found"
            api_response = self.collections_api.collections_remove_schedule_from_collection(collection_id, schedule_id)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    # Workflows functions
    def get_all_workflows(self):
        """Get the list of all workflows of the Alteryx server"""
        try:
            api_response = self.workflows_api.workflows_get_workflows()
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def get_workflow_by_id(self, workflow_id: str):
        """Get a workflow by its ID"""
        try:
            api_response = self.workflows_api.workflows_get_workflow(workflow_id)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def update_workflow_name_or_comment(self, workflow_id: str, name: str, comment: str):
        """Update a workflow name or comment by its ID"""
        try:
            workflow = self.workflows_api.workflows_get_workflow(workflow_id)
            if not workflow:
                return "Error: Workflow not found"
            workflow_details = workflow
            latest_version_id = server_client.WorkflowVersionView(
                workflow_details.versions[len(workflow_details.versions) - 1]
            ).version_id
            contract = server_client.UpdateWorkflowContract(
                name=name if name else workflow_details.name,
                version_id=latest_version_id,
                make_published=workflow_details.is_public,
                owner_id=workflow_details.owner_id,
                worker_tag=workflow_details.worker_tag,
                district_tags=workflow_details.district_tags,
                comment=comment if comment else workflow_details.comments,
                is_public=workflow_details.is_public,
                is_ready_for_migration=workflow_details.is_ready_for_migration,
                others_may_download=workflow_details.others_may_download,
                others_can_execute=workflow_details.others_can_execute,
                execution_mode=workflow_details.execution_mode,
                has_private_data_exemption=workflow_details.has_private_data_exemption,
            )
            api_response = self.workflows_api.workflows_update_workflow(workflow_id, contract)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def transfer_workflow(self, workflow_id: str, new_owner_id: str):
        """Transfer a workflow to a new owner by its ID"""
        try:
            workflow = self.workflows_api.workflows_get_workflow(workflow_id)
            if not workflow:
                return "Error: Workflow not found"
            new_owner = self.users_api.users_get_user(new_owner_id)
            if not new_owner:
                return "Error: New owner not found"
            contract = server_client.TransferWorkflowContract(owner_id=new_owner_id)
            api_response = self.workflows_api.workflows_transfer_workflow(workflow_id, contract)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def get_workflow_jobs(self, workflow_id: str):
        """Get the list of jobs for an existing workflow"""
        try:
            workflow = self.workflows_api.workflows_get_workflow(workflow_id)
            if not workflow:
                return "Error: Workflow not found"
            api_response = self.workflows_api.workflows_get_jobs_for_workflow(workflow_id)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def start_workflow_execution(self, workflow_id: str, input_data: list[InputData] = None):
        """Start a workflow execution by its ID and return the job ID. This will create a new job and add it to the execution queue.
        This call will return a job ID that can be used to get the job details. Once the job is executed, 
        the results can be retrieved via the produced JobID
        The input data is a list of name-value pairs, each containing a name and value."""
        try:
            workflow = self.workflows_api.workflows_get_workflow(workflow_id)
            if not workflow:
                return "Error: Workflow not found"
            questions = self.workflows_api.workflows_get_workflow_questions(workflow_id)
            if (not questions or len(questions) == 0) and (input_data):
                return "Error: Workflow has no questions, input data not allowed"
            if questions and len(questions) > 0:
                for question in questions:
                    if question.name not in [item.name for item in input_data]:
                        return f"Error: Input data must contain the question '{question.name}'"
                    
            # Proper type conversion
            workflow = server_client.WorkflowView(workflow)
            contract = server_client.EnqueueJobContract(worker_tag=workflow.worker_tag, questions=input_data)
            api_response = self.workflows_api.workflows_enqueue(workflow_id, contract)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"


    def execute_workflow_with_monitoring(
            self,
            workflow_id: str, 
            input_data: Optional[List[InputData]] = None, 
            wait_for_completion: bool = True,
            timeout_seconds: int = 3600,
            poll_interval_seconds: int = 5
    ):
        """ Execute a workflow and monitor its execution status. 
        This call will return a jobID as well as the complete job details. 
        The input data parameter is a list of name-value pairs, each containing a name and value. """
        try:
            workflow = self.workflows_api.workflows_get_workflow(workflow_id)
            if not workflow:
                return "Error: Workflow not found"
            
            questions = self.workflows_api.workflows_get_workflow_questions(workflow_id)
            if (not questions or len(questions) == 0) and (input_data):
                return "Error: Workflow has no questions, input data not allowed"
            if questions and len(questions) > 0:
                for question in questions:
                    if question.name not in [item.name for item in input_data]:
                        return f"Error: Input data must contain the question '{question.name}'"

            # Start the workflow execution
            contract = server_client.EnqueueJobContract(worker_tag=workflow.worker_tag, questions=input_data)
            job_response = self.workflows_api.workflows_enqueue(workflow_id, contract)

            # Parse the job response to get the job ID
            if job_response.status != "Queued":
                # Out put error
                return pprint.pformat({
                    "success": False,
                    "job_id": job_id,
                    "status": job_response.status,
                    "message": f"Error: Workfow was not successfully started. Current JobID:'{job_response.id}"
                })

            # Extract the job id
            job_id = job_response.id

            if not wait_for_completion:
                return pprint.pformat({
                    "success": True,
                    "job_id": job_id,
                    "status": "Started",
                    "message": "Job started successfully, not waiting for completion"
                })

            start_time = time.time()

            while True:
                # Check if timeout exceeded
                if time.time() - start_time > timeout_seconds:
                    return pprint.pformat({
                        "success": False,
                        "job_id": job_id,
                        "status": "Timeout",
                        "error": f"Job execution timed out after {timeout_seconds} seconds"
                    })
                
                # Get job status
                try:
                    job_details = self.jobs_api.jobs_get_job_v3(job_id)
                    
                    if job_details.status in ["Completed", "Cancelled"]:
                        # Get final job details including outputs and messages
                        final_details = job_details
                        job_messages = self.jobs_api.jobs_get_job_messages(job_id=job_id)
                        return  pprint.pformat({
                                "success": job_details.status == "Completed",
                                "job_id": job_id,
                                "status": job_details.status,
                                "job_details": final_details,
                                "execution_time_seconds": time.time() - start_time
                            })
                    # else:
                    #     return pprint.pformat({
                    #         "success": False,
                    #         "job_id": job_id,
                    #         "status": "Failed",
                    #         "error": "Could not extract status from job details, continuing to monitor..."
                    #     }) 
                    
                except Exception as e:
                    return pprint.pformat({
                        "success": False,
                        "job_id": job_id,
                        "status": "Failed",
                        "error": f"Error checking job status: {str(e)}"
                    })           
                # Wait before next check
                time.sleep(poll_interval_seconds)

        except ApiException as e:
            return pprint.pformat({
                "success": False,
                "error": f"Unexpected error: {str(e)}",
                "job_id": None,
                "status": "Failed"
            })
            


    # Users functions
    def get_all_users(self):
        """Get the list of all users of the Alteryx server"""
        try:
            api_response = self.users_api.users_get_users()
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def get_user_by_id(self, user_id: str):
        """Get a user by their ID"""
        try:
            api_response = self.users_api.users_get_user(user_id)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def get_user_by_email(self, email: str):
        """Get a user by their email"""
        try:
            api_response = self.users_api.users_get_users(email=email)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def get_user_by_name(self, name: str):
        """Get a user by their last name"""
        try:
            api_response = self.users_api.users_get_users(last_name=name)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def get_user_by_first_name(self, first_name: str):
        """Get a user by their first name"""
        try:
            api_response = self.users_api.users_get_users(first_name=first_name)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def get_all_user_assets(self, user_id: str):
        """Get all the assets for a user"""
        try:
            api_response = self.users_api.users_get_users_assets(user_id)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def get_user_assets_by_type(self, user_id: str, asset_type: str):
        """Get all the assets for a user by type. The asset type can be 'Workflow', 'Collection',
        'Connection', 'Credential' or 'All'."""
        try:
            api_response = self.users_api.users_get_users_assets(user_id, asset_type)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def update_user_details(self, user_id: str, first_name: str, last_name: str, email: str):
        """Update details of an existing user by their ID. Can be used to update any of the user's details."""
        try:
            user_details = self.users_api.users_get_user(user_id)
            
            if not user_details:
                return "Error: User not found"
            contract = server_client.UpdateUserContract(
                id=user_details.id,
                first_name=first_name if first_name else user_details.first_name,
                last_name=last_name if last_name else user_details.last_name,
                email=email if email else user_details.email,
                role=user_details.role,
                default_worker_tag=user_details.default_worker_tag,
                can_schedule_jobs=user_details.can_schedule_jobs,
                can_prioritize_jobs=user_details.can_prioritize_jobs,
                can_assign_jobs=user_details.can_assign_jobs,
                can_create_collections=user_details.can_create_collections,
                is_api_enabled=user_details.is_api_enabled,
                default_credential_id=user_details.default_credential_id,
                is_account_locked=user_details.is_account_locked,
                is_active=user_details.is_active,
                is_validated=user_details.is_validated,
                time_zone=user_details.time_zone,
                language=user_details.language,
                can_create_and_update_dcm=user_details.can_create_and_update_dcm,
                can_share_for_execution_dcm=user_details.can_share_for_execution_dcm,
                can_share_for_collaboration_dcm=user_details.can_share_for_collaboration_dcm,
                can_manage_generic_vaults_dcm=user_details.can_manage_generic_vaults_dcm,
            )
            api_response = self.users_api.users_update_user(user_id, contract)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def transfer_all_assets(
        self,
        user_id: str,
        new_owner_id: str,
        transfer_workflows: bool,
        transfer_schedules: bool,
        transfer_collections: bool,
    ):
        """Transfer all assets (workflows, schedules, collections) owned by one user to another."""
        try:
            user = self.users_api.users_get_user(user_id)
            if not user:
                return "Error: User not found"
            new_owner = self.users_api.users_get_user(new_owner_id)
            if not new_owner:
                return "Error: New owner not found"
            contract = server_client.TransferUserAssetsContract(
                owner_id=new_owner_id,
                transfer_workflows=transfer_workflows,
                transfer_schedules=transfer_schedules,
                transfer_collections=transfer_collections,
            )
            api_response = self.users_api.users_transfer_assets(user_id, contract)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def deactivate_user(self, user_id: str):
        """Deactivate a user by their ID"""
        try:
            user = self.users_api.users_get_user(user_id)
            if not user:
                return "Error: User not found"
            api_response = self.users_api.users_deactivate_user(user_id)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def reset_user_password(self, user_id: str):
        """Reset a user's password by their ID"""
        try:
            user = self.users_api.users_get_user(user_id)
            if not user:
                return "Error: User not found"
            api_response = self.users_api.users_reset_user_password(user_id)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    # Jobs functions
    def get_all_job_messages(self, job_id: str):
        """Get all the messages for a job"""
        try:
            api_response = self.jobs_api.jobs_get_job_v3(job_id, include_messages=True)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def get_job_by_id(self, job_id: str):
        """Retrieve details about an existing job and its current state. Only app workflows can be used."""
        try:
            api_response = self.jobs_api.jobs_get_job_v3(job_id)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    # Schedules functions
    def get_all_schedules(self):
        """Get the list of all schedules of the Alteryx server"""
        try:
            api_response = self.schedules_api.schedules_get_schedules()
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def get_schedule_by_id(self, schedule_id: str):
        """Get a schedule by its ID"""
        try:
            api_response = self.schedules_api.schedules_get_schedule(schedule_id)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def deactivate_schedule(self, schedule_id: str):
        """Deactivate a schedule by its ID"""
        try:
            schedule = self.schedules_api.schedules_get_schedule(schedule_id)
            if not schedule:
                return "Error: Schedule not found"
            
            contract = server_client.UpdateScheduleContract(
                workflow_id=schedule.workflow_id,
                owner_id=schedule.owner_id,
                iteration=schedule.iteration,
                name=schedule.name,
                comment=schedule.comment,
                priority=schedule.priority,
                worker_tag=schedule.worker_tag,
                enabled=False,
                credential_id=schedule.credential_id,
                time_zone=schedule.time_zone,
                questions=schedule.questions,
            )
            api_response = self.schedules_api.schedules_update_schedule(schedule_id, contract)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def activate_schedule(self, schedule_id: str):
        """Activate a schedule by its ID"""
        try:
            schedule = self.schedules_api.schedules_get_schedule(schedule_id)
            if not schedule:
                return "Error: Schedule not found"
            
            contract = server_client.UpdateScheduleContract(
                workflow_id=schedule.workflow_id,
                owner_id=schedule.owner_id,
                iteration=schedule.iteration,
                name=schedule.name,
                comment=schedule.comment,
                priority=schedule.priority,
                worker_tag=schedule.worker_tag,
                enabled=True,
                credential_id=schedule.credential_id,
                time_zone=schedule.time_zone,
                questions=schedule.questions,
            )
            api_response = self.schedules_api.schedules_update_schedule(schedule_id, contract)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def update_schedule_name_or_comment(self, schedule_id: str, name: str, comment: str):
        """Update the name or comment of a schedule by its ID"""
        try:
            schedule = self.schedules_api.schedules_get_schedule(schedule_id)
            if not schedule:
                return "Error: Schedule not found"
            
            contract = server_client.UpdateScheduleContract(
                workflow_id=schedule.workflow_id,
                owner_id=schedule.owner_id,
                iteration=schedule.iteration,
                name=name if name else schedule.name,
                comment=comment if comment else schedule.comment,
                priority=schedule.priority,
                worker_tag=schedule.worker_tag,
                enabled=schedule.enabled,
                credential_id=schedule.credential_id,
                time_zone=schedule.time_zone,
                questions=schedule.questions,
            )
            api_response = self.schedules_api.schedules_update_schedule(schedule_id, contract)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def change_schedule_owner(self, schedule_id: str, new_owner_id: str):
        """Change the owner of a schedule by its ID"""
        try:
            schedule = self.schedules_api.schedules_get_schedule(schedule_id)
            if not schedule:
                return "Error: Schedule not found"
            
            contract = server_client.UpdateScheduleContract(
                workflow_id=schedule.workflow_id,
                owner_id=new_owner_id if new_owner_id else schedule.owner_id,
                iteration=schedule.iteration,
                name=schedule.name,
                comment=schedule.comment,
                priority=schedule.priority,
                worker_tag=schedule.worker_tag,
                enabled=schedule.enabled,
                credential_id=schedule.credential_id,
                time_zone=schedule.time_zone,
                questions=schedule.questions,
            )
            api_response = self.schedules_api.schedules_update_schedule(schedule_id, contract)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    # Credentials functions
    def get_all_credentials(self):
        """Get the list of all accessible credentials of the Alteryx server"""
        try:
            api_response = self.credentials_api.credentials_get_credentials()
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def get_credential_by_id(self, credential_id: str):
        """Get the details of an existing credential."""
        try:
            api_response = self.credentials_api.credentials_get_credential(credential_id)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    # Connections functions
    def lookup_connection(self, connection_id: str):
        """Lookup a DCM Connection as referenced in workflows"""
        try:
            api_response = self.dcm_api.d_cme_lookup_dcm_connection(connection_id)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    def get_connection_by_id(self, connection_id: str):
        """Get a connection by its ID"""
        try:
            api_response = self.dcm_api.d_cme_get_dcm_connection(connection_id)
            return pprint.pformat(api_response)
        except ApiException as e:
            return f"Error: {e}"

    # Workflow file functions
    def download_workflow_package_file(self, workflow_id: str, output_directory: str):
        """Download a workflow package file by its ID and save it to the local directory"""
        try:
            api_response = self.workflows_api.workflows_get_workflow(workflow_id)
            if api_response is None:
                return "Error: Workflow not found"
            
            # Download the workflow file
            api_response = self.workflows_api.workflows_download_workflow(workflow_id)
            if api_response is None:
                return "Error: Failed to download workflow"
            
            # Create the output directory if it doesn't exist
            if not os.path.exists(output_directory):
                os.makedirs(output_directory)
            
            # Save the workflow file to the output directory
            with open(
                f"{output_directory}/{workflow_id}.yxzp",
                "wb" if not os.path.exists(f"{output_directory}/{workflow_id}.yxzp") else "wb+",
            ) as f:
                f.write(api_response)

            return (
                f"Workflow {workflow_id} downloaded successfully. File saved to '{output_directory}/{workflow_id}.yxzp'"
            )
        except ApiException as e:
            return f"Error: {e.body}"

    def get_workflow_xml(self, workflow_id: str):
        """Get the XML representation of a workflow file by its ID"""
        try:
            api_response = self.workflows_api.workflows_get_workflow(workflow_id)
            if api_response is None:
                return "Error: Workflow not found"
            
             # Download the workflow file
            api_response = self.workflows_api.workflows_download_workflow(workflow_id)
            if api_response is None:
                return "Error: Failed to download workflow"
                
            temp_directory = tempfile.gettempdir()
            
            with open(
                f"{temp_directory}/{workflow_id}.yxzp",
                "wb" if not os.path.exists(f"{temp_directory}/{workflow_id}.yxz") else "wb+",
            ) as f:
                f.write(api_response)

            new_directory = f"{temp_directory}/{workflow_id}"
            if os.path.exists(new_directory):
                shutil.rmtree(new_directory)
            os.makedirs(new_directory)
            
            with zipfile.ZipFile(f"{temp_directory}/{workflow_id}.yxzp", "r") as zip_ref:
                zip_ref.extractall(new_directory)
            
            yxmd_files = [file for file in os.listdir(new_directory) if file.endswith(".yxmd")]
            if len(yxmd_files) == 0:
                return "Error: Workflow XML file not found after unzipping"
            
            yxmd_file = yxmd_files[0]
            
            # Read as binary first, then decode as UTF-8
            with open(f"{new_directory}/{yxmd_file}", "rb") as f:
                binary_content = f.read()
                try:
                    # Try to decode as UTF-8
                    return binary_content.decode('utf-8')
                except UnicodeDecodeError:
                    # If UTF-8 fails, return the binary content as a string representation
                    return binary_content
            
        except ApiException as e:
            return f"Error: {e}"
        

    # def get_workflow_tools(self, workflow_id: str):
    #     """Get all the tools and their properties of a workflow by the workflow ID"""
    #     api_response = self.workflows_api.workflows_get_workflow(workflow_id)
    #     if api_response is None:
    #         return "Error: Workflow not found"
        
    #         # Download the workflow file
    #     api_response = self.workflows_api.workflows_download_workflow(workflow_id)
    #     if api_response is None:
    #         return "Error: Failed to download workflow"
            
    #     temp_directory = tempfile.gettempdir()
        
    #     with open(
    #         f"{temp_directory}/{workflow_id}.yxzp",
    #         "wb" if not os.path.exists(f"{temp_directory}/{workflow_id}.yxz") else "wb+",
    #     ) as f:
    #         f.write(api_response)

    #     new_directory = f"{temp_directory}/{workflow_id}"
    #     if os.path.exists(new_directory):
    #         shutil.rmtree(new_directory)
    #     os.makedirs(new_directory)
        
    #     with zipfile.ZipFile(f"{temp_directory}/{workflow_id}.yxzp", "r") as zip_ref:
    #         zip_ref.extractall(new_directory)
        
    #     yxmd_files = [file for file in os.listdir(new_directory) if file.endswith(".yxmd")]
    #     if len(yxmd_files) == 0:
    #         return "Error: Workflow XML file not found after unzipping"
        
    #     yxmd_file = yxmd_files[0]

    #     # Read as binary first, then decode as UTF-8
    #     with open(f"{new_directory}/{yxmd_file}", "rb") as f:
    #         binary_content = f.read()
    #         try:
    #             # Try to decode as UTF-8
    #             xml_content = binary_content.decode('utf-8')
    #         except UnicodeDecodeError:
    #             # If UTF-8 fails, return the binary content as a string representation
    #             xml_content = binary_content

    #     # Parse the XML content 
    #     root = ET.fromstring(xml_content)
    #     tools = root.findall(".//Node")
    #     tools_dict = {}
    #     for tool in tools:
    #         tool_id = tool.get("ToolID")
    #         tool_dict = {}
    #         for prop in tool.findall(".//Configuration"):
    #             prop_name = prop.get("Name")
    #             prop_value = prop.get("Value")
    #             tool_dict[prop_name] = prop_value
    #         tools_dict[tool_id] = tool_dict
    #     return tools_dict



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class Member(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "active_directory_object": "ADObject",
        "user_id": "str",
        "date_added_to_group": "datetime",
        "added_by_user_id": "str",
    }

    attribute_map = {
        "active_directory_object": "activeDirectoryObject",
        "user_id": "userId",
        "date_added_to_group": "dateAddedToGroup",
        "added_by_user_id": "addedByUserId",
    }

    def __init__(
        self,
        active_directory_object=None,
        user_id=None,
        date_added_to_group=None,
        added_by_user_id=None,
        _configuration=None,
    ):  # noqa: E501
        """Member - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._active_directory_object = None
        self._user_id = None
        self._date_added_to_group = None
        self._added_by_user_id = None
        self.discriminator = None

        if active_directory_object is not None:
            self.active_directory_object = active_directory_object
        if user_id is not None:
            self.user_id = user_id
        if date_added_to_group is not None:
            self.date_added_to_group = date_added_to_group
        if added_by_user_id is not None:
            self.added_by_user_id = added_by_user_id

    @property
    def active_directory_object(self):
        """Gets the active_directory_object of this Member.  # noqa: E501


        :return: The active_directory_object of this Member.  # noqa: E501
        :rtype: ADObject
        """
        return self._active_directory_object

    @active_directory_object.setter
    def active_directory_object(self, active_directory_object):
        """Sets the active_directory_object of this Member.


        :param active_directory_object: The active_directory_object of this Member.  # noqa: E501
        :type: ADObject
        """

        self._active_directory_object = active_directory_object

    @property
    def user_id(self):
        """Gets the user_id of this Member.  # noqa: E501


        :return: The user_id of this Member.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this Member.


        :param user_id: The user_id of this Member.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def date_added_to_group(self):
        """Gets the date_added_to_group of this Member.  # noqa: E501


        :return: The date_added_to_group of this Member.  # noqa: E501
        :rtype: datetime
        """
        return self._date_added_to_group

    @date_added_to_group.setter
    def date_added_to_group(self, date_added_to_group):
        """Sets the date_added_to_group of this Member.


        :param date_added_to_group: The date_added_to_group of this Member.  # noqa: E501
        :type: datetime
        """

        self._date_added_to_group = date_added_to_group

    @property
    def added_by_user_id(self):
        """Gets the added_by_user_id of this Member.  # noqa: E501


        :return: The added_by_user_id of this Member.  # noqa: E501
        :rtype: str
        """
        return self._added_by_user_id

    @added_by_user_id.setter
    def added_by_user_id(self, added_by_user_id):
        """Sets the added_by_user_id of this Member.


        :param added_by_user_id: The added_by_user_id of this Member.  # noqa: E501
        :type: str
        """

        self._added_by_user_id = added_by_user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(Member, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Member):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Member):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from src.server_client.api_client import ApiClient


class ServerConnectionsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def server_connections_add_user_group_to_server_data_connection(self, data_connection_id, contract, **kwargs):  # noqa: E501
        """Share an existing Server data connection with an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_add_user_group_to_server_data_connection(data_connection_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_connection_id: Identifier for an existing Server data connection. (required)
        :param AddServerConnectionUserGroupContract contract:  (required)
        :return: ServerConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.server_connections_add_user_group_to_server_data_connection_with_http_info(
                data_connection_id, contract, **kwargs
            )  # noqa: E501
        else:
            (data) = self.server_connections_add_user_group_to_server_data_connection_with_http_info(
                data_connection_id, contract, **kwargs
            )  # noqa: E501
            return data

    def server_connections_add_user_group_to_server_data_connection_with_http_info(
        self, data_connection_id, contract, **kwargs
    ):  # noqa: E501
        """Share an existing Server data connection with an existing user group.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_add_user_group_to_server_data_connection_with_http_info(data_connection_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_connection_id: Identifier for an existing Server data connection. (required)
        :param AddServerConnectionUserGroupContract contract:  (required)
        :return: ServerConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["data_connection_id", "contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method server_connections_add_user_group_to_server_data_connection" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'data_connection_id' is set
        if self.api_client.client_side_validation and (
            "data_connection_id" not in params or params["data_connection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `data_connection_id` when calling `server_connections_add_user_group_to_server_data_connection`"
            )  # noqa: E501
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `contract` when calling `server_connections_add_user_group_to_server_data_connection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "data_connection_id" in params:
            path_params["dataConnectionId"] = params["data_connection_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/serverDataConnections/{dataConnectionId}/userGroups",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ServerConnectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def server_connections_add_user_to_server_data_connection(self, data_connection_id, contract, **kwargs):  # noqa: E501
        """Share an existing Server data connection with an existing user.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_add_user_to_server_data_connection(data_connection_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_connection_id: Identifier for an existing Server data connection. (required)
        :param AddServerConnectionUserContract contract:  (required)
        :return: ServerConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.server_connections_add_user_to_server_data_connection_with_http_info(
                data_connection_id, contract, **kwargs
            )  # noqa: E501
        else:
            (data) = self.server_connections_add_user_to_server_data_connection_with_http_info(
                data_connection_id, contract, **kwargs
            )  # noqa: E501
            return data

    def server_connections_add_user_to_server_data_connection_with_http_info(
        self, data_connection_id, contract, **kwargs
    ):  # noqa: E501
        """Share an existing Server data connection with an existing user.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_add_user_to_server_data_connection_with_http_info(data_connection_id, contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_connection_id: Identifier for an existing Server data connection. (required)
        :param AddServerConnectionUserContract contract:  (required)
        :return: ServerConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["data_connection_id", "contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method server_connections_add_user_to_server_data_connection" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'data_connection_id' is set
        if self.api_client.client_side_validation and (
            "data_connection_id" not in params or params["data_connection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `data_connection_id` when calling `server_connections_add_user_to_server_data_connection`"
            )  # noqa: E501
        # verify the required parameter 'contract' is set
        if self.api_client.client_side_validation and ("contract" not in params or params["contract"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `contract` when calling `server_connections_add_user_to_server_data_connection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "data_connection_id" in params:
            path_params["dataConnectionId"] = params["data_connection_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "contract" in params:
            body_params = params["contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/serverDataConnections/{dataConnectionId}/users",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ServerConnectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def server_connections_delete_server_data_connection(self, data_connection_id, **kwargs):  # noqa: E501
        """Delete an existing Server data connection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_delete_server_data_connection(data_connection_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_connection_id: Identifier for an existing Server data connection. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.server_connections_delete_server_data_connection_with_http_info(data_connection_id, **kwargs)  # noqa: E501
        else:
            (data) = self.server_connections_delete_server_data_connection_with_http_info(data_connection_id, **kwargs)  # noqa: E501
            return data

    def server_connections_delete_server_data_connection_with_http_info(self, data_connection_id, **kwargs):  # noqa: E501
        """Delete an existing Server data connection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_delete_server_data_connection_with_http_info(data_connection_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_connection_id: Identifier for an existing Server data connection. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["data_connection_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method server_connections_delete_server_data_connection" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'data_connection_id' is set
        if self.api_client.client_side_validation and (
            "data_connection_id" not in params or params["data_connection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `data_connection_id` when calling `server_connections_delete_server_data_connection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "data_connection_id" in params:
            path_params["dataConnectionId"] = params["data_connection_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/serverDataConnections/{dataConnectionId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def server_connections_get_server_data_connection(self, data_connection_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing Server data connection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_get_server_data_connection(data_connection_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_connection_id: Identifier for an existing Server data connection. (required)
        :return: ServerConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.server_connections_get_server_data_connection_with_http_info(data_connection_id, **kwargs)  # noqa: E501
        else:
            (data) = self.server_connections_get_server_data_connection_with_http_info(data_connection_id, **kwargs)  # noqa: E501
            return data

    def server_connections_get_server_data_connection_with_http_info(self, data_connection_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing Server data connection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_get_server_data_connection_with_http_info(data_connection_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_connection_id: Identifier for an existing Server data connection. (required)
        :return: ServerConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["data_connection_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method server_connections_get_server_data_connection" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'data_connection_id' is set
        if self.api_client.client_side_validation and (
            "data_connection_id" not in params or params["data_connection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `data_connection_id` when calling `server_connections_get_server_data_connection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "data_connection_id" in params:
            path_params["dataConnectionId"] = params["data_connection_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/serverDataConnections/{dataConnectionId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ServerConnectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def server_connections_get_server_data_connections(self, **kwargs):  # noqa: E501
        """Retrieve all accessible Server data connection records.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_get_server_data_connections(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view:
        :return: list[ReducedServerConnectionView]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.server_connections_get_server_data_connections_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.server_connections_get_server_data_connections_with_http_info(**kwargs)  # noqa: E501
            return data

    def server_connections_get_server_data_connections_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve all accessible Server data connection records.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_get_server_data_connections_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str view:
        :return: list[ReducedServerConnectionView]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["view"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method server_connections_get_server_data_connections" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "view" in params:
            query_params.append(("view", params["view"]))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/serverDataConnections",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[ReducedServerConnectionView]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def server_connections_remove_user_from_server_data_connection(self, data_connection_id, user_id, **kwargs):  # noqa: E501
        """Remove a user's permissions to use an existing Server data connection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_remove_user_from_server_data_connection(data_connection_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_connection_id: Identifier for an existing Server data connection. (required)
        :param str user_id: Identifier for an existing user. (required)
        :return: ServerConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.server_connections_remove_user_from_server_data_connection_with_http_info(
                data_connection_id, user_id, **kwargs
            )  # noqa: E501
        else:
            (data) = self.server_connections_remove_user_from_server_data_connection_with_http_info(
                data_connection_id, user_id, **kwargs
            )  # noqa: E501
            return data

    def server_connections_remove_user_from_server_data_connection_with_http_info(
        self, data_connection_id, user_id, **kwargs
    ):  # noqa: E501
        """Remove a user's permissions to use an existing Server data connection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_remove_user_from_server_data_connection_with_http_info(data_connection_id, user_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_connection_id: Identifier for an existing Server data connection. (required)
        :param str user_id: Identifier for an existing user. (required)
        :return: ServerConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["data_connection_id", "user_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method server_connections_remove_user_from_server_data_connection" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'data_connection_id' is set
        if self.api_client.client_side_validation and (
            "data_connection_id" not in params or params["data_connection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `data_connection_id` when calling `server_connections_remove_user_from_server_data_connection`"
            )  # noqa: E501
        # verify the required parameter 'user_id' is set
        if self.api_client.client_side_validation and ("user_id" not in params or params["user_id"] is None):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `user_id` when calling `server_connections_remove_user_from_server_data_connection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "data_connection_id" in params:
            path_params["dataConnectionId"] = params["data_connection_id"]  # noqa: E501
        if "user_id" in params:
            path_params["userId"] = params["user_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/serverDataConnections/{dataConnectionId}/users/{userId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ServerConnectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def server_connections_remove_user_group_from_server_data_connection(
        self, data_connection_id, user_group_id, **kwargs
    ):  # noqa: E501
        """Remove a user group's permissions to use an existing Server data connection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_remove_user_group_from_server_data_connection(data_connection_id, user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_connection_id: Identifier for an existing Server data connection. (required)
        :param str user_group_id: Identifier for an existing user group. (required)
        :return: ServerConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.server_connections_remove_user_group_from_server_data_connection_with_http_info(
                data_connection_id, user_group_id, **kwargs
            )  # noqa: E501
        else:
            (data) = self.server_connections_remove_user_group_from_server_data_connection_with_http_info(
                data_connection_id, user_group_id, **kwargs
            )  # noqa: E501
            return data

    def server_connections_remove_user_group_from_server_data_connection_with_http_info(
        self, data_connection_id, user_group_id, **kwargs
    ):  # noqa: E501
        """Remove a user group's permissions to use an existing Server data connection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_remove_user_group_from_server_data_connection_with_http_info(data_connection_id, user_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_connection_id: Identifier for an existing Server data connection. (required)
        :param str user_group_id: Identifier for an existing user group. (required)
        :return: ServerConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["data_connection_id", "user_group_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method server_connections_remove_user_group_from_server_data_connection" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'data_connection_id' is set
        if self.api_client.client_side_validation and (
            "data_connection_id" not in params or params["data_connection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `data_connection_id` when calling `server_connections_remove_user_group_from_server_data_connection`"
            )  # noqa: E501
        # verify the required parameter 'user_group_id' is set
        if self.api_client.client_side_validation and (
            "user_group_id" not in params or params["user_group_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `user_group_id` when calling `server_connections_remove_user_group_from_server_data_connection`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "data_connection_id" in params:
            path_params["dataConnectionId"] = params["data_connection_id"]  # noqa: E501
        if "user_group_id" in params:
            path_params["userGroupId"] = params["user_group_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/serverDataConnections/{dataConnectionId}/userGroups/{userGroupId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ServerConnectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def server_connections_update_server_data_connection_name(
        self, data_connection_id, update_server_connection_contract, **kwargs
    ):  # noqa: E501
        """Update the connection name of an existing Server data connection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_update_server_data_connection_name(data_connection_id, update_server_connection_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_connection_id: Identifier for an existing Server data connection. (required)
        :param UpdateServerConnectionContract update_server_connection_contract:  (required)
        :return: ServerConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.server_connections_update_server_data_connection_name_with_http_info(
                data_connection_id, update_server_connection_contract, **kwargs
            )  # noqa: E501
        else:
            (data) = self.server_connections_update_server_data_connection_name_with_http_info(
                data_connection_id, update_server_connection_contract, **kwargs
            )  # noqa: E501
            return data

    def server_connections_update_server_data_connection_name_with_http_info(
        self, data_connection_id, update_server_connection_contract, **kwargs
    ):  # noqa: E501
        """Update the connection name of an existing Server data connection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.server_connections_update_server_data_connection_name_with_http_info(data_connection_id, update_server_connection_contract, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str data_connection_id: Identifier for an existing Server data connection. (required)
        :param UpdateServerConnectionContract update_server_connection_contract:  (required)
        :return: ServerConnectionView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["data_connection_id", "update_server_connection_contract"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method server_connections_update_server_data_connection_name" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'data_connection_id' is set
        if self.api_client.client_side_validation and (
            "data_connection_id" not in params or params["data_connection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `data_connection_id` when calling `server_connections_update_server_data_connection_name`"
            )  # noqa: E501
        # verify the required parameter 'update_server_connection_contract' is set
        if self.api_client.client_side_validation and (
            "update_server_connection_contract" not in params or params["update_server_connection_contract"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `update_server_connection_contract` when calling `server_connections_update_server_data_connection_name`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "data_connection_id" in params:
            path_params["dataConnectionId"] = params["data_connection_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "update_server_connection_contract" in params:
            body_params = params["update_server_connection_contract"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json", "text/json", "application/xml", "text/xml", "application/x-www-form-urlencoded"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/serverDataConnections/{dataConnectionId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ServerConnectionView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from src.server_client.configuration import Configuration


class UserGroupView(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "name": "str",
        "date_added": "datetime",
        "role": "str",
        "credential_ids": "list[str]",
        "connection_ids": "list[str]",
        "members": "list[Member]",
    }

    attribute_map = {
        "id": "id",
        "name": "name",
        "date_added": "dateAdded",
        "role": "role",
        "credential_ids": "credentialIds",
        "connection_ids": "connectionIds",
        "members": "members",
    }

    def __init__(
        self,
        id=None,
        name=None,
        date_added=None,
        role=None,
        credential_ids=None,
        connection_ids=None,
        members=None,
        _configuration=None,
    ):  # noqa: E501
        """UserGroupView - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._date_added = None
        self._role = None
        self._credential_ids = None
        self._connection_ids = None
        self._members = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.date_added = date_added
        self.role = role
        if credential_ids is not None:
            self.credential_ids = credential_ids
        if connection_ids is not None:
            self.connection_ids = connection_ids
        if members is not None:
            self.members = members

    @property
    def id(self):
        """Gets the id of this UserGroupView.  # noqa: E501


        :return: The id of this UserGroupView.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this UserGroupView.


        :param id: The id of this UserGroupView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this UserGroupView.  # noqa: E501


        :return: The name of this UserGroupView.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UserGroupView.


        :param name: The name of this UserGroupView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def date_added(self):
        """Gets the date_added of this UserGroupView.  # noqa: E501


        :return: The date_added of this UserGroupView.  # noqa: E501
        :rtype: datetime
        """
        return self._date_added

    @date_added.setter
    def date_added(self, date_added):
        """Sets the date_added of this UserGroupView.


        :param date_added: The date_added of this UserGroupView.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and date_added is None:
            raise ValueError("Invalid value for `date_added`, must not be `None`")  # noqa: E501

        self._date_added = date_added

    @property
    def role(self):
        """Gets the role of this UserGroupView.  # noqa: E501


        :return: The role of this UserGroupView.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role):
        """Sets the role of this UserGroupView.


        :param role: The role of this UserGroupView.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and role is None:
            raise ValueError("Invalid value for `role`, must not be `None`")  # noqa: E501
        allowed_values = ["NoAccess", "Viewer", "Member", "Artisan", "Curator", "Evaluated"]  # noqa: E501
        if self._configuration.client_side_validation and role not in allowed_values:
            raise ValueError(
                "Invalid value for `role` ({0}), must be one of {1}".format(role, allowed_values)  # noqa: E501
            )

        self._role = role

    @property
    def credential_ids(self):
        """Gets the credential_ids of this UserGroupView.  # noqa: E501


        :return: The credential_ids of this UserGroupView.  # noqa: E501
        :rtype: list[str]
        """
        return self._credential_ids

    @credential_ids.setter
    def credential_ids(self, credential_ids):
        """Sets the credential_ids of this UserGroupView.


        :param credential_ids: The credential_ids of this UserGroupView.  # noqa: E501
        :type: list[str]
        """

        self._credential_ids = credential_ids

    @property
    def connection_ids(self):
        """Gets the connection_ids of this UserGroupView.  # noqa: E501


        :return: The connection_ids of this UserGroupView.  # noqa: E501
        :rtype: list[str]
        """
        return self._connection_ids

    @connection_ids.setter
    def connection_ids(self, connection_ids):
        """Sets the connection_ids of this UserGroupView.


        :param connection_ids: The connection_ids of this UserGroupView.  # noqa: E501
        :type: list[str]
        """

        self._connection_ids = connection_ids

    @property
    def members(self):
        """Gets the members of this UserGroupView.  # noqa: E501


        :return: The members of this UserGroupView.  # noqa: E501
        :rtype: list[Member]
        """
        return self._members

    @members.setter
    def members(self, members):
        """Sets the members of this UserGroupView.


        :param members: The members of this UserGroupView.  # noqa: E501
        :type: list[Member]
        """

        self._members = members

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserGroupView, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserGroupView):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserGroupView):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
Alteryx Server API V3

No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

OpenAPI spec version: 3

Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from src.server_client.api_client import ApiClient


class DCMEConnectApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def d_cme_connect_get_dcme_connection_for_connect(self, connection_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing DCM connection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_connect_get_dcme_connection_for_connect(connection_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str connection_id: Identifier for an existing DCM connection. (required)
        :return: DCMEGetConnectionForConnectView
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.d_cme_connect_get_dcme_connection_for_connect_with_http_info(connection_id, **kwargs)  # noqa: E501
        else:
            (data) = self.d_cme_connect_get_dcme_connection_for_connect_with_http_info(connection_id, **kwargs)  # noqa: E501
            return data

    def d_cme_connect_get_dcme_connection_for_connect_with_http_info(self, connection_id, **kwargs):  # noqa: E501
        """Retrieve details about an existing DCM connection.  # noqa: E501

        Only Curators can use this API endpoint.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.d_cme_connect_get_dcme_connection_for_connect_with_http_info(connection_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str connection_id: Identifier for an existing DCM connection. (required)
        :return: DCMEGetConnectionForConnectView
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["connection_id"]  # noqa: E501
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in six.iteritems(params["kwargs"]):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method d_cme_connect_get_dcme_connection_for_connect" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'connection_id' is set
        if self.api_client.client_side_validation and (
            "connection_id" not in params or params["connection_id"] is None
        ):  # noqa: E501
            raise ValueError(
                "Missing the required parameter `connection_id` when calling `d_cme_connect_get_dcme_connection_for_connect`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "connection_id" in params:
            path_params["connectionId"] = params["connection_id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "application/xml", "text/xml"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        return self.api_client.call_api(
            "/v3/DCMEConnections/{connectionId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="DCMEGetConnectionForConnectView",  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )
